"""This module contains the AnalysisInputResponse domain model."""

from mythx_models.request import AnalysisSubmissionRequest


class AnalysisInputResponse(AnalysisSubmissionRequest):
    pass
